package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.QmsTruckFeign;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:09
 */
@RestController
@RequestMapping("${api.version}/qms")
public class QMSController extends BaseRESTfulController {

    @Autowired
    private QmsTruckFeign qmsTruckFeign;

    @ApiOperation(value="触发电子围栏-->新增排队实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/addQueueResult")
    public RESTfulResult addQueueResult(String orderNumber){
        return qmsTruckFeign.addQueueResult(orderNumber);
    }


    @ApiOperation(value="指令接收-->新增排队链表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/addQueueList")
    public RESTfulResult addQueueList(@RequestBody(required = false) Map<String, Object> mapValue){
        return qmsTruckFeign.addQueueList(mapValue);
    }

    @ApiOperation(value="指令接收")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(130)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/orderReceive")
    public RESTfulResult orderReceive(@RequestBody(required=false) Map<String,Object> mapValue,
                                      Integer apiId,
                                      Integer pageNum,
                                      Integer pageSize
    ){
        return qmsTruckFeign.orderReceive(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }


    @ApiOperation(value="查询排队申请")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(125)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueApply")
    public RESTfulResult getQueueApply(@RequestBody(required=false) Map<String,Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize
    ){
        return qmsTruckFeign.getQueueApply(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }


    @ApiOperation(value="查询排队开始")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(128)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueListByQueueUp")
    public RESTfulResult getQueueListByQueueUp(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer gridId
    ){
        return qmsTruckFeign.getQueueListByQueueUp(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, gridId);
    }


    @ApiOperation(value="排队转移-->新增排队链表:实绩Id、门岗名称、转移原因")
    @PostMapping("/changeQueue")
    public RESTfulResult changeQueue(@RequestBody(required=false) Map<String, Object> mapValue){
        return qmsTruckFeign.changeQueue(mapValue);
    }


    @ApiOperation(value="查询排队转移")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(124)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getChangeQueue")
    public RESTfulResult getAllEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize
    ){
        return qmsTruckFeign.getChangeQueue(mapValue == null ? new HashMap<>(): mapValue, apiId, pageNum, pageSize);
    }


    @ApiOperation(value="排队取消-->修改排队链表deleted为1")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/queueCancel")
    public RESTfulResult queueCancel(@RequestBody(required=false) Map<String, Object> mapValue){
        return qmsTruckFeign.queueCancel(mapValue);
    }

    @ApiOperation(value="查询排队取消")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(131)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueCancel")
    public RESTfulResult getQueueCancel(@RequestBody(required=false) Map<String,Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize
    ){
        return qmsTruckFeign.getQueueCancel(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="通过Id查询排队取消实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/getQueueCancelByResultId/{resultId}")
    public RESTfulResult getQueueCancelByResultId(@PathVariable("resultId") Integer resultId){
        return qmsTruckFeign.getQueueCancelByResultId(resultId);
    }


    @ApiOperation(value="修改排队取消实绩：时间、原因")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/updateQueueCancel")
    public RESTfulResult updateQueueCancel(@RequestBody(required=false) Map<String,Object> mapValue){
        return qmsTruckFeign.updateQueueCancel(mapValue);
    }


    @ApiOperation(value="排队插队-->修改排队链表顺序号为最小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/queueCutInLine")
    public RESTfulResult queueCutInLine(@RequestBody(required=false) Map<String, Object> mapValue){
        return qmsTruckFeign.queueCutInLine(mapValue);
    }


    @ApiOperation(value="查询排队插队")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(132)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueInsert")
    public RESTfulResult getQueueInsert(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize
    ){
        return qmsTruckFeign.getQueueInsert(mapValue == null?new HashMap<>():mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="排队结束-->修改deleted = 1")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/queueEndByPDA")
    public RESTfulResult queueEnd(@RequestBody(required=false) Map<String, Object> mapValue){
        return qmsTruckFeign.queueEnd(mapValue);
    }

    @ApiOperation(value="查询排队结束")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(133)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueEndResult")
    public RESTfulResult getQueueEndResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize
    ){
        return qmsTruckFeign.getQueueEndResult(mapValue == null?new HashMap<>():mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="汽车监控")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(135)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/capacityMonitor")
    public RESTfulResult capacityMonitor(@RequestBody(required=false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize
    ){
        return qmsTruckFeign.capacityMonitor(mapValue == null ? new HashMap<>(): mapValue, apiId, pageNum, pageSize);
    }


    @ApiOperation(value="链表监控")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(134)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/listMonitor")
    public RESTfulResult listMonitor(@RequestBody(required=false) Map<String,Object> mapValue,
                                     Integer apiId,
                                     Integer pageNum,
                                     Integer pageSize
    ){return qmsTruckFeign.listMonitor(mapValue == null ? new HashMap<>(): mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="查询各仓库，门岗的排队状态列表")
    @PostMapping("/getQueueStatusList")
    public RESTfulResult getQueueStatusList(){
        return qmsTruckFeign.getQueueStatusList();
    }

    @ApiOperation(value="通过车牌号查询司机接单")
    @PostMapping("/getOrderReceive/{capacityNumber}")
    public RESTfulResult getOrderReceive(@PathVariable("capacityNumber") String capacityNumber){
        return qmsTruckFeign.getOrderReceive(capacityNumber);
    }

    @ApiOperation(value="通过车牌号取消排队")
    @PostMapping("/cancelQueue")
    public RESTfulResult cancelQueue(@RequestBody Map<String,Object> mapValue){
        return qmsTruckFeign.cancelQueue(mapValue);
    }

    @ApiOperation(value="查询执行中订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(156)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllExecutionOrder")
    public RESTfulResult getAllExecutionOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer orderType,
                                              Integer status
    ){
        return qmsTruckFeign.getAllExecutionOrder(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, orderType, status);
    }
}
