package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.TmsshipFeign;
import com.steerinfo.dil.feign.TmsTrainFeign;
import com.steerinfo.dil.feign.TmsTruckFeign;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:11
 */

@RestController
@RequestMapping("${api.version}/tms")
public class TMSController extends BaseRESTfulController {
    @Autowired
    private TmsTruckFeign tmsTruckFeign;
    @Autowired
    private TmsTrainFeign tmsTrainFeign;
    @Autowired
    TmsshipFeign tmsshipFeign;

    /*======================================船运==========================================*/
    /**
     * 驳船
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getBargeOperationList")
    @ApiOperation(value = "展示驳船")
    public RESTfulResult getBargeOperationList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getBargeOperationList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("selectBargeOperation/{bargeOperationId}")
    @ApiOperation(value = "通过id查询驳船")
    RESTfulResult selectBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId) {
        return tmsshipFeign.selectBargeOperation(bargeOperationId);
    }

    @PostMapping("getBargeOperation/{bargeOperationId}")
    @ApiOperation(value = "查询驳船")
    RESTfulResult getBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId) {
        return tmsshipFeign.getBargeOperation(bargeOperationId);
    }

    @PostMapping("deleteBargeOperation/{bargeOperationId}")
    @ApiOperation(value = "逻辑删除驳船")
    RESTfulResult deleteBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId) {
        return tmsshipFeign.deleteBargeOperation(bargeOperationId);
    }

    @PostMapping("updateBargeOperation")
    @ApiOperation(value = "修改驳船")
    RESTfulResult updateBargeOperation(@RequestBody Map<String, Object> tmsshipBargeOperation) {
        return tmsshipFeign.updateBargeOperation(tmsshipBargeOperation);
    }

    @PostMapping("addBargeOperation")
    @ApiOperation(value = "新增驳船")
    RESTfulResult addBargeOperation(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.addBargeOperation(map);
    }

    @PostMapping("addTmsShipEntryWharyResult")
    @ApiOperation(value = "新增抵港")
    RESTfulResult addTmsShipEntryWharyResult(@RequestBody Map<String, Object> mapVal) {
        return tmsshipFeign.addTmsShipEntryWharyResult(mapVal);
    }

    @PostMapping("addTmsShipOutWharyResult")
    @ApiOperation(value = "新增离港")
    RESTfulResult addTmsShipOutWharyResult(@RequestBody Map<String, Object> mapVal) {
        return tmsshipFeign.addTmsShipOutWharyResult(mapVal);
    }

    /**
     * 装船
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getLoadShipList")
    @ApiOperation(value = "展示装船")
    public RESTfulResult getLoadShipList(@RequestBody(required = false) Map<String, Object> mapValue,
                                         Integer pageNum,
                                         Integer pageSize,
                                         Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getLoadShipList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("getLoadShip/{resultId}")
    @ApiOperation(value = "查询装船")
    RESTfulResult getLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.getLoadShip(resultId);
    }

    @PostMapping("selectLoadShip/{resultId}")
    @ApiOperation(value = "通过id查询装船")
    RESTfulResult selectLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.selectLoadShip(resultId);
    }

    @PostMapping("deleteLoadShip/{resultId}")
    @ApiOperation(value = "逻辑删除装船")
    RESTfulResult deleteLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.deleteLoadShip(resultId);
    }

    @PostMapping("updateLoadShip")
    @ApiOperation(value = "修改装船")
    RESTfulResult updateLoadShip(@RequestBody Map<String, Object> tmsshipLoadShipResult) {
        return tmsshipFeign.updateLoadShip(tmsshipLoadShipResult);
    }

    @PostMapping("addLoadShip")
    @ApiOperation(value = "新增装船")
    RESTfulResult addLoadShip(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.addLoadShip(map);
    }

    /**
     * 位置作业
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getShipLocationList")
    @ApiOperation(value = "展示位置作业")
    public RESTfulResult getShipLocationList(@RequestBody(required = false) Map<String, Object> mapValue,
                                             Integer pageNum,
                                             Integer pageSize,
                                             Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getShipLocationList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("getShipLocation/{locationId}")
    @ApiOperation(value = "查询位置作业")
    RESTfulResult getShipLocation(@PathVariable("locationId") BigDecimal locationId) {
        return tmsshipFeign.getShipLocation(locationId);
    }

    @PostMapping("selectShipLocation/{locationId}")
    @ApiOperation(value = "通过id查询位置作业")
    RESTfulResult selectShipLocation(@PathVariable("locationId") BigDecimal locationId) {
        return tmsshipFeign.selectShipLocation(locationId);
    }

    @PostMapping("deleteShipLocation/{locationId}")
    @ApiOperation(value = "逻辑删除位置作业")
    RESTfulResult deleteShipLocation(@PathVariable("locationId") BigDecimal locationId) {
        return tmsshipFeign.deleteShipLocation(locationId);
    }

    @PostMapping("updateShipLocation")
    @ApiOperation(value = "修改位置作业")
    RESTfulResult updateShipLocation(@RequestBody Map<String, Object> tmsshipShipLocation) {
        return tmsshipFeign.updateShipLocation(tmsshipShipLocation);
    }

    @PostMapping("addShipLocation")
    @ApiOperation(value = "新增位置作业")
    RESTfulResult addShipLocation(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.addShipLocation(map);
    }

    /**
     * 水路货物运单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("listAllOrders")
    @ApiOperation(value = "展示水路货物运单")
    public RESTfulResult listAllOrders(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.listAllOrders(mapValue, pageNum, pageSize, apiId);
    }

    /**
     * 展示船只信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getCapacityList")
    @ApiOperation(value = "展示船只信息")
    public RESTfulResult getCapacityList(@RequestBody(required = false) Map<String, Object> mapValue,
                                         Integer pageNum,
                                         Integer pageSize,
                                         Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getCapacityList(mapValue, pageNum, pageSize, apiId);
    }

    /**
     * 卸船作业
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getUnLoadShipList")
    @ApiOperation(value = "展示卸船作业信息列表")
    public RESTfulResult getUnLoadShipList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getUnLoadShipList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("getUnloadShip/{resultId}")
    @ApiOperation(value = "查询卸船作业")
    RESTfulResult getUnloadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.getUnloadShip(resultId);
    }

    @PostMapping("selectUnLoadShip/{resultId}")
    @ApiOperation(value = "通过id查询卸船作业")
    RESTfulResult selectUnLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.selectUnLoadShip(resultId);
    }

    @PostMapping("deleteUnLoadShip/{resultId}")
    @ApiOperation(value = "逻辑删除卸船作业")
    RESTfulResult deleteUnLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.deleteUnLoadShip(resultId);
    }

    @PostMapping("updateUnLoadShip")
    @ApiOperation(value = "修改卸船作业")
    RESTfulResult updateUnLoadShip(@RequestBody Map<String, Object> tmsshipUnloadShipResult) {
        return tmsshipFeign.updateUnLoadShip(tmsshipUnloadShipResult);
    }

    @PostMapping("addUnLoadShip")
    @ApiOperation(value = "新增卸船作业")
    RESTfulResult addUnLoadShip(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.addUnLoadShip(map);
    }

    /**
     * 水分质检
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getWaterQualityResultList")
    @ApiOperation(value = "展示水分质检信息列表")
    public RESTfulResult getWaterQualityResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                   Integer pageNum,
                                                   Integer pageSize,
                                                   Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getWaterQualityResultList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("getWaterQuality/{resultId}")
    @ApiOperation(value = "查询水分质检")
    RESTfulResult getWaterQuality(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.getWaterQuality(resultId);
    }

    @PostMapping("selectWaterQualityResult/{resultId}")
    @ApiOperation(value = "通过id查询水分质检")
    RESTfulResult selectWaterQualityResult(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.selectWaterQualityResult(resultId);
    }

    @PostMapping("deleteWaterQualityResult/{resultId}")
    @ApiOperation(value = "逻辑删除水分质检")
    RESTfulResult deleteWaterQualityResult(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.deleteWaterQualityResult(resultId);
    }

    @PostMapping("updateWaterQualityResult")
    @ApiOperation(value = "修改水分质检")
    RESTfulResult updateWaterQualityResult(@RequestBody Map<String, Object> tmsshipWaterQualityResult) {
        return tmsshipFeign.updateWaterQualityResult(tmsshipWaterQualityResult);
    }

    @PostMapping("addWaterQualityResult")
    @ApiOperation(value = "新增水分质检")
    RESTfulResult addWaterQualityResult(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.addWaterQualityResult(map);
    }

    /**
     * 船只信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getCapacities")
    @ApiOperation(value = "展示船只信息列表")
    public RESTfulResult getCapacities(BigDecimal instructionsId,
                                       @RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getCapacities(instructionsId, mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("getInstructionsCapacity/{instructionsCapacityId}")
    @ApiOperation(value = "查询船只信息")
    RESTfulResult getInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId) {
        return tmsshipFeign.getInstructionsCapacity(instructionsCapacityId);
    }

    @PostMapping("deleteInstructionsCapacity/{instructionsCapacityId}")
    @ApiOperation(value = "逻辑删除船只信息")
    RESTfulResult deleteInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId) {
        return tmsshipFeign.deleteInstructionsCapacity(instructionsCapacityId);
    }

    @PostMapping("updateInstructionsCapacity")
    @ApiOperation(value = "修改船只信息")
    RESTfulResult updateInstructionsCapacity(@RequestBody Map<String, Object> omsshipInstructionsCapacity) {
        return tmsshipFeign.updateInstructionsCapacity(omsshipInstructionsCapacity);
    }

    @PostMapping("addInstructionsCapacity")
    @ApiOperation(value = "新增船只信息")
    RESTfulResult addInstructionsCapacity(@RequestBody Map<String, Object> omsshipInstructionsCapacity) {
        return tmsshipFeign.addInstructionsCapacity(omsshipInstructionsCapacity);
    }

    /**
     * 装船指令
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getShipMentInstructionsList")
    @ApiOperation(value = "展示装船指令列表")
    public RESTfulResult getShipMentInstructionsList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getShipMentInstructionsList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("getShipmentInstructions/{instructionsId}")
    @ApiOperation(value = "查询装船指令")
    RESTfulResult getShipmentInstructions(@PathVariable("instructionsId") BigDecimal instructionsId) {
        return tmsshipFeign.getShipmentInstructions(instructionsId);
    }

    @PostMapping("deleteByPrimaryKey/{instructionsId}")
    @ApiOperation(value = "逻辑删除装船指令")
    RESTfulResult deleteByPrimaryKey(@PathVariable("instructionsId") BigDecimal instructionsId) {
        return tmsshipFeign.deleteByPrimaryKey(instructionsId);
    }

    @PostMapping("updateIssueStatus/{shipmentInstructionsId}")
    @ApiOperation(value = "修改状态")
    RESTfulResult updateIssueStatus(@PathVariable("shipmentInstructionsId") BigDecimal shipmentInstructionsId) {
        return tmsshipFeign.updateIssueStatus(shipmentInstructionsId);
    }

    @PostMapping("updateShipmentInstructions")
    @ApiOperation(value = "修改装船指令")
    RESTfulResult updateShipmentInstructions(@RequestBody Map<String, Object> omsshipShipmentInstructions) {
        return tmsshipFeign.updateShipmentInstructions(omsshipShipmentInstructions);
    }

    @PostMapping("addShipmentInstructions")
    @ApiOperation(value = "新增装船指令")
    RESTfulResult addShipmentInstructions(@RequestBody Map<String, Object> omsshipShipmentInstructions) {
        return tmsshipFeign.addShipmentInstructions(omsshipShipmentInstructions);
    }

    /**
     * 货权转移
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getAmsshipCargoTranferResultList")
    @ApiOperation(value = "展示货权转移")
    public RESTfulResult getAmsshipCargoTranferResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getAmsshipCargoTranferResultList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("insertamsshipCargoTransferResult")
    @ApiOperation(value = "新增货权转移")
    RESTfulResult insertamsshipCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult) {
        return tmsshipFeign.insertamsshipCargoTransferResult(amsshipCargoTransferResult);
    }

    @PostMapping("deleteByCargoId/{cargoTransferResultId}")
    @ApiOperation(value = "逻辑删除货权转移")
    RESTfulResult deleteByCargoId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId) {
        return tmsshipFeign.deleteByCargoId(cargoTransferResultId);
    }

    @PostMapping("editCargoTransferResult")
    @ApiOperation(value = "修改货权转移")
    RESTfulResult editCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult) {
        return tmsshipFeign.editCargoTransferResult(amsshipCargoTransferResult);
    }

    @PostMapping("selectByCargoTranferResultId/{cargoTransferResultId}")
    @ApiOperation(value = "通过id查询货权转移")
    RESTfulResult selectByCargoTranferResultId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId) {
        return tmsshipFeign.selectByCargoTranferResultId(cargoTransferResultId);
    }

    /**
     * 提货委托
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getAmsshipDeliveryAttroneyList")
    @ApiOperation(value = "展示提货委托")
    public RESTfulResult getAmsshipDeliveryAttroneyList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                        Integer pageNum,
                                                        Integer pageSize,
                                                        Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getAmsshipDeliveryAttroneyList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("insertshipDeliveryAttorney")
    @ApiOperation(value = "新增提货委托")
    RESTfulResult insertshipDeliveryAttorney(@RequestBody Map<String, Object> amsshipDeliveryAttorney) {
        return tmsshipFeign.insertshipDeliveryAttorney(amsshipDeliveryAttorney);
    }

    @PostMapping("deleteByAttorneyId/{attorneyId}")
    @ApiOperation(value = "逻辑删除提货委托")
    RESTfulResult deleteByAttorneyId(@PathVariable("attorneyId") Integer attorneyId) {
        return tmsshipFeign.deleteByAttorneyId(attorneyId);
    }

    @PostMapping("editDeliveryAttroney")
    @ApiOperation(value = "修改提货委托")
    RESTfulResult editDeliveryAttroney(@RequestBody Map<String, Object> amsshipDeliveryAttorney) {
        return tmsshipFeign.editDeliveryAttroney(amsshipDeliveryAttorney);
    }

    @PostMapping("getDeliveryAttorneyId/{attorneyId}")
    @ApiOperation(value = "通过id查询提货委托")
    RESTfulResult getDeliveryAttorneyId(@PathVariable("attorneyId") Integer attorneyId) {
        return tmsshipFeign.getDeliveryAttorneyId(attorneyId);
    }

    @PostMapping("sendDeliveryAttorneyStatus/{attorneyId}")
    @ApiOperation(value = "下发提货委托")
    RESTfulResult sendDeliveryAttorneyStatus(@PathVariable("attorneyId") Integer attorneyId) {
        return tmsshipFeign.sendDeliveryAttorneyStatus(attorneyId);
    }

    /**
     * 放货通知
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getshipDeliveryNoticeList")
    @ApiOperation(value = "展示放货通知")
    public RESTfulResult getshipDeliveryNoticeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                   Integer pageNum,
                                                   Integer pageSize,
                                                   Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getshipDeliveryNoticeList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("insertDeliveryNotice")
    @ApiOperation(value = "新增放货通知")
    RESTfulResult insertDeliveryNotice(@RequestBody Map<String, Object> amsshipDeliveryNotice) {
        return tmsshipFeign.insertDeliveryNotice(amsshipDeliveryNotice);
    }

    @PostMapping("deleteByNoticeId/{noticeId}")
    @ApiOperation(value = "逻辑删除放货通知")
    RESTfulResult deleteByNoticeId(@PathVariable("noticeId") Integer noticeId) {
        return tmsshipFeign.deleteByNoticeId(noticeId);
    }

    @PostMapping("editDeliveryNotice")
    @ApiOperation(value = "修改放货通知")
    RESTfulResult editDeliveryNotice(@RequestBody Map<String, Object> editDeliveryNotice) {
        return tmsshipFeign.editDeliveryNotice(editDeliveryNotice);
    }

    @PostMapping("selectByNoticeId/{noticeId}")
    @ApiOperation(value = "通过id查询放货通知")
    RESTfulResult selectByNoticeId(@PathVariable("noticeId") Integer noticeId) {
        return tmsshipFeign.selectByNoticeId(noticeId);
    }

    @PostMapping("sendDeliveryNotice/{noticeId}")
    @ApiOperation(value = "下发放货通知")
    RESTfulResult sendDeliveryNotice(@PathVariable("noticeId") Integer noticeId) {
        return tmsshipFeign.sendDeliveryNotice(noticeId);
    }


    /**
     * 下拉框
     * @return
     */
    @GetMapping("getGroupId")
    @ApiOperation(value = "得到下拉")
    public RESTfulResult getGroupId(){
        return tmsshipFeign.getGroupId();
    }

    @GetMapping("getCargoId")
    @ApiOperation(value = "得到货物下拉")
    public RESTfulResult getCargoId(){
        return tmsshipFeign.getCargoId();
    }

    @GetMapping("insertBetchId")
    @ApiOperation(value = "得到批次下拉")
    public RESTfulResult insertBetchId(){
        return tmsshipFeign.insertBetchId();
    }

    @GetMapping("getAttorneyId")
    @ApiOperation(value = "得到提货下拉")
    public RESTfulResult getAttorneyId(){
        return tmsshipFeign.getAttorneyId();
    }

    @GetMapping("getNoticeId")
    @ApiOperation(value = "得到放货下拉")
    public RESTfulResult getNoticeId(){
        return tmsshipFeign.getNoticeId();
    }

    @GetMapping("getPortName")
    @ApiOperation(value = "得到货权转移单位")
    public RESTfulResult getPortName(){
        return tmsshipFeign.getPortName();
    }

    @GetMapping("getPortId")
    @ApiOperation(value = "得到港口下拉")
    public RESTfulResult getPortId(){
        return tmsshipFeign.getPortId();
    }

    @GetMapping("getRmRawId")
    @ApiOperation(value = "得到仓库下拉")
    public RESTfulResult getRmRawId(){
        return tmsshipFeign.getRmRawId();
    }

    @GetMapping("getPierId")
    @ApiOperation(value = "得到码头下拉")
    public RESTfulResult getPierId(){
        return tmsshipFeign.getPierId();
    }

    @GetMapping("getResultNumber")
    @ApiOperation(value = "得到实绩编号下拉")
    public RESTfulResult getResultNumber(){
        return tmsshipFeign.getResultNumber();
    }

    @GetMapping("getCarrier")
    @ApiOperation(value = "得到承运商下拉")
    public RESTfulResult getCarrier(){
        return tmsshipFeign.getCarrier();
    }

    @GetMapping("getShipperId")
    @ApiOperation(value = "得到托运方下拉")
    public RESTfulResult getShipperId(){
        return tmsshipFeign.getShipper();
    }

    @GetMapping("getOrderId")
    @ApiOperation(value = "得到装船指令下拉")
    public RESTfulResult getTask(){
        return tmsshipFeign.getTask();
    }

    @GetMapping("getCapacityId")
    @ApiOperation(value = "得到船下拉")
    public RESTfulResult getCapacityId(){
        return tmsshipFeign.getCapacityId();
    }


    /*======================================火运==========================================*/




    //************************************TmstrainLoadingResultController********************
    @ApiOperation(value="查询装车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(58)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/getTmstrainWagonLoad")
    public RESTfulResult getTmstrainWagonLoad(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize){
        return tmsTrainFeign.getTmstrainWagonLoad(mapValue == null?new HashMap<>():mapValue, apiId, pageNum, pageSize);
    }


    @ApiOperation(value="新增车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainLoadingResult", value = "车皮装车对象", required = false, dataType = "TmstrainLoadingResult")
    })
    @PostMapping(value = "/insertTmstrainLoadingResult")
    public RESTfulResult insertTmstrainLoadingResult(@RequestBody(required = false) Map<String, Object> map){
        return tmsTrainFeign.insertTmstrainLoadingResult(map);
    }


    @ApiOperation(value="通过主键查询车皮装车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "车皮装车主键", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/getTmstrainLoadingResultByResultId/{resultId}")
    public RESTfulResult getTmstrainLoadingResultByResultId(@PathVariable("resultId") BigDecimal resultId){
        return tmsTrainFeign.getTmstrainLoadingResultByResultId(resultId);
    }

    @ApiOperation(value="通过主键修改车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainLoadingResult", value = "修改车皮装车map", required = false, dataType = "TmstrainWagonLoadResult")
    })
    @PostMapping(value = "/upadteTmstrainLoadingResultByResultId")
    public RESTfulResult upadteTmstrainLoadingResultByResultId(@RequestBody(required = false) Map<String, Object> map) {
        return tmsTrainFeign.upadteTmstrainLoadingResultByResultId(map);
    }

    @ApiOperation(value="通过主键删除车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "主键ID", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/deleteTmstrainLoadingResultByResultId")
    public RESTfulResult deleteTmstrainLoadingResultByResultId(@RequestParam BigDecimal resultId){
        return tmsTrainFeign.deleteTmstrainLoadingResultByResultId(resultId);
    }

    //********************下拉框**********************

    @ApiOperation(value="获取发站地点名称")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getSendStationName")
    public RESTfulResult getSendStationName(){
        return tmsTrainFeign.getSendStationName();
    }

    @ApiOperation(value="获取到站地点名称")
    @GetMapping(value = "/getArrivalStationName")
    public RESTfulResult getArrivalStationName(){
        return tmsTrainFeign.getArrivalStationName();
    }

    @ApiOperation(value="获取批次ID")
    @GetMapping(value = "/getBatchId")
    public RESTfulResult getBatchId(){
        return tmsTrainFeign.getBatchId();
    }

    @ApiOperation(value="获取装车车皮号")
    @GetMapping(value = "/getWagonNo")
    public RESTfulResult getWagonNo(){
        return tmsTrainFeign.getWagonNo();
    }

    @ApiOperation(value="查询所有发运计划")
    @GetMapping(value = "/getRailPlan")
    public RESTfulResult getRailPlan(){
        return tmsTrainFeign.getRailPlan();
    }

    @GetMapping(value = "/getDilBatch")
    public RESTfulResult getDilBatch(){
        return tmsTruckFeign.getDilBatch();
    }

    @GetMapping(value = "/getCarrierId")
    public RESTfulResult getCarrierId(){
        return tmsTruckFeign.getCarrier();
    }

    @GetMapping(value = "/getLine")
    public RESTfulResult getLine(){
        return tmsTruckFeign.getLine();
    }

    @GetMapping(value = "/getWarehouse")
    public RESTfulResult getWarehouse(){
        return tmsTruckFeign.getWarehouse();
    }

    @GetMapping(value = "/getGatepost")
    public RESTfulResult getGatepost(){
        return tmsTruckFeign.getGatepost();
    }

    @GetMapping(value = "/getAPO")
    public RESTfulResult getAPO(){
        return tmsTruckFeign.getAPO();
    }

    @GetMapping(value = "/getFuCapacityId")
    public RESTfulResult getFuCapacityId(){
        return tmsTruckFeign.getFuCapacityId();
    }

    @GetMapping(value = "/getPort")
    public RESTfulResult getPort(){
        return tmsTruckFeign.getPort();
    }

    @ApiOperation(value="查询卸车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(60)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/getTmstrainWagonUnLoad")
    public RESTfulResult getTmstrainWagonUnLoad(@RequestBody(required=false) Map<String,Object> mapValue,
                                                Integer apiId,
                                                Integer pageNum,
                                                Integer pageSize){
        return tmsTrainFeign.getTmstrainWagonUnLoad(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="通过主键删除车皮卸车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "unloadingId", value = "主键ID", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/deleteTmstrainWagonUnLoadResultByUnLoadingId")
    public RESTfulResult deleteTmstrainWagonUnLoadResultByUnLoadingId(@RequestParam BigDecimal unloadingId){
        return tmsTrainFeign.deleteTmstrainWagonUnLoadResultByUnLoadingId(unloadingId);
    }

    @ApiOperation(value="新增车皮卸车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainWagonUnloadResult", value = "车皮卸车对象", required = false, dataType = "TmstrainWagonUnloadResult")
    })
    @PostMapping(value = "/insertTmstrainWagonUnLoadResult")
    public RESTfulResult insertTmstrainWagonUnLoadResult(@RequestBody(required = false) Map<String, Object> tmstrainWagonUnloadResult){
        return tmsTrainFeign.insertTmstrainWagonUnLoadResult(tmstrainWagonUnloadResult);
    }

    @ApiOperation(value="通过主键修改车皮卸车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainWagonUnloadResult", value = "车皮卸车对象", required = false, dataType = "TmstrainWagonUnloadResult")
    })
    @PostMapping(value = "/upadteTmstrainWagonUnLoadResultByUnLoadingId")
    public RESTfulResult upadteTmstrainWagonUnLoadResultByUnLoadingId(@RequestBody(required = false) Map<String, Object> tmstrainWagonUnloadResult){
        return tmsTrainFeign.upadteTmstrainWagonUnLoadResultByUnLoadingId(tmstrainWagonUnloadResult);
    }

    @ApiOperation(value="查看火运实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(65)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/getTmstrainresult")
    public RESTfulResult getTmstrainresult(@RequestBody(required=false) Map<String,Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize){
        return tmsTrainFeign.getTmstrainresult(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="通过主键查询车皮卸车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "unloadingId", value = "车皮卸车主键", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/getTmstrainWagonUnLoadResultByUnLoadingId/{unloadingId}")
    public RESTfulResult getTmstrainWagonUnLoadResultByUnLoadingId(@PathVariable("unloadingId") BigDecimal unloadingId) {
        return tmsTrainFeign.getTmstrainWagonUnLoadResultByUnLoadingId(unloadingId);
    }

        //下拉框
    @ApiOperation(value="获取卸车地点名称")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getUnloadingPointName")
    public RESTfulResult getUnloadingPointName(){
        return tmsTrainFeign.getUnloadingPointName();
    }

    @ApiOperation(value="获取卸车路径名称")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getUnloadingRouteName")
    public RESTfulResult getUnloadingRouteName(){
        return tmsTrainFeign.getUnloadingRouteName();
    }


    @ApiOperation(value="查询请车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(57)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllWagonPlease")
    public RESTfulResult getAllWagonPlease(@RequestBody(required=false) Map<String,Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer status){

        return tmsTrainFeign.getAllWagonPlease(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, status);
    }

    @ApiOperation(value="通过Id查询请车作业")
    @PostMapping ("/getWagonPleaseById/{resultId}")
    public RESTfulResult getWagonPleaseById(@PathVariable("resultId")Integer resultId){
        return tmsTrainFeign.getWagonPleaseById(resultId);
    }

    @ApiOperation(value="新增请车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amstrainWagonPlease", value = "请车作业对象", required = false, dataType = "AmstrainWagonPlease"),
    })
    @PostMapping("/addWagonPlease")
    public RESTfulResult addWagonPlease(@RequestBody(required = false) Map<String, Object> tmstrainPleaseApproveResult){
        return tmsTrainFeign.addWagonPlease(tmstrainPleaseApproveResult);
    }

    @ApiOperation(value="修改请车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainPleaseApproveResult", value = "请车作业实绩对象", required = false, dataType = "TmstrainPleaseApproveResult"),
    })
    @PostMapping("/updateWagonPlease")
    public RESTfulResult updateWagonPlease(@RequestBody(required = false) Map<String, Object> tmstrainPleaseApproveResult){
        return tmsTrainFeign.updateWagonPlease(tmstrainPleaseApproveResult);
    }

    @ApiOperation(value="逻辑删除请车作业 设置状态码为 3")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainPleaseApproveResult", value = "请车作业实绩对象", required = false, dataType = "TmstrainPleaseApproveResult"),
    })
    @PostMapping("/deleteWagonPlease/{resultId}")
    public RESTfulResult deleteWagonPlease(@PathVariable("resultId") Integer resultId){
        return tmsTrainFeign.deleteWagonPlease(resultId);
    }

    @ApiOperation(value="下发请车作业 设置状态码为 1")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "请车作业实绩对象", required = false, dataType = "Integer"),
    })
    @PostMapping("/sendWagonPlease/{resultId}")
    public RESTfulResult sendWagonPlease(@PathVariable("resultId") Integer resultId){
        return tmsTrainFeign.sendWagonPlease(resultId);
    }

    //下拉框

    @ApiOperation(value="查询所有发货单位")
    @GetMapping("/getShipper")
    public RESTfulResult getShipper(){
        return tmsTrainFeign.getShipper();
    }

    @ApiOperation(value="查询批车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(70)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getApproveAllWagonPlease")
    public RESTfulResult getApproveAllWagonPlease(@RequestBody(required=false) Map<String,Object> mapValue,
                                                  Integer apiId,
                                                  Integer pageNum,
                                                  Integer pageSize){
        return tmsTrainFeign.getApproveAllWagonPlease(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="通过Id查询批车作业")
    @PostMapping ("/getApproveWagonPleaseById/{resultId}")
    public RESTfulResult getApproveWagonPleaseById(@PathVariable("resultId")Integer resultId){
        return tmsTrainFeign.getApproveWagonPleaseById(resultId);
    }

    @ApiOperation(value="新增批车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainPleaseApproveResult", value = "请车作业实绩对象", required = false, dataType = "TmstrainPleaseApproveResult"),
    })
    @PostMapping("/addApproveWagonPlease")
    public RESTfulResult addApproveWagonPlease(@RequestBody(required = false) Map<String, Object> tmstrainPleaseApproveResult){
        return tmsTrainFeign.addApproveWagonPlease(tmstrainPleaseApproveResult);
    }

    @ApiOperation(value="修改批车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainPleaseApproveResult", value = "请车作业实绩对象", required = false, dataType = "TmstrainPleaseApproveResult"),
    })
    @PostMapping("/updateApproveWagonPlease")
    public RESTfulResult updateApproveWagonPlease(@RequestBody(required = false) Map<String, Object> tmstrainPleaseApproveResult){
        return tmsTrainFeign.updateApproveWagonPlease(tmstrainPleaseApproveResult);
    }

    @ApiOperation(value="逻辑删除批车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "请车作业实绩对象", required = false, dataType = "Integer"),
    })
    @PostMapping("/deleteApproveWagonPlease/{resultId}")
    public RESTfulResult deleteApproveWagonPlease(@PathVariable("resultId") Integer resultId){
        return tmsTrainFeign.deleteApproveWagonPlease(resultId);
    }


        /*======================================汽运==========================================*/

    @ApiOperation(value="查询运输预约")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(79)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllPurPlan")
    public RESTfulResult getAllPurPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer status) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsTruckFeign.getAllPurPlan(mapValue, apiId, pageNum, pageSize, status);
    }

    /*
    不知道谁写的
     */
    @PostMapping("/getAllPurPlan/{apiId}")
    public RESTfulResult getDetailListByCon(@PathVariable("apiId") Integer apiId,
                                            @RequestBody(required = false) Map<String, Object> mapValue,
                                            Integer pageNum,
                                            Integer pageSize,
                                            String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsTruckFeign.getDetailListByCon(apiId, mapValue, pageNum, pageSize, con);
    }

    @ApiOperation(value = "通过Id查询请车作业")
    @PostMapping("/getPurPlanById/{planId}")
    public RESTfulResult getPurPlanById(@PathVariable("planId") Integer planId) {
        return tmsTruckFeign.getPurPlanById(planId);
    }

    @ApiOperation(value = "新增运输计划 状态：0")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amstruckPurplan", value = "运输计划实绩对象", required = false, dataType = "AmstruckPurplan"),
    })
    @PostMapping("/addPurPlan")
    public RESTfulResult addPurPlan(@RequestBody Map<String, Object> map) {
        return tmsTruckFeign.addPurPlan(map);
    }

    @ApiOperation(value = "下发运输计划 状态：1")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/sendPurPlan/{planId}")
    public RESTfulResult sendPurPlan(@PathVariable("planId") Integer planId) {
        return tmsTruckFeign.sendPurPlan(planId);
    }

    @ApiOperation(value = "接收运输计划 状态：2")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/receptionPurPlan/{planId}")
    public RESTfulResult receptionPurPlan(@PathVariable("planId") Integer planId) {
        return tmsTruckFeign.receptionPurPlan(planId);
    }

    @ApiOperation(value = "逻辑删除运输计划 状态：3")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/deletePurPlan/{planId}")
    public RESTfulResult deletePurPlan(@PathVariable("planId") Integer planId) {
        return tmsTruckFeign.deletePurPlan(planId);
    }

    //**************************************************************************************
    @ApiOperation(value = "查询要分派的计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(82)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getDecomposedPlan")
    public RESTfulResult getDecomposedPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer planId,
                                           Integer status) {
        return tmsTruckFeign.getDecomposedPlan(mapValue == null? new HashMap<>() : mapValue, apiId, pageNum, pageSize, planId, status);
    }


    //********************************************omsTruckOrderController*****************************

    @ApiOperation(value = "查询所有运输订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(86)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllTruckOrder")
    public RESTfulResult getAllTruckOrder(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer orderStatus,
                                          Integer planId,
                                          Integer orderType) {
        return tmsTruckFeign.getAllTruckOrder(mapValue == null? new HashMap<>() : mapValue, apiId, pageNum, pageSize, orderStatus, planId, orderType);
    }

    @ApiOperation(value = "不适用表头返回数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/getAllTruckOrderReturnListMap")
    public RESTfulResult getAllTruckOrder(Integer orderStatus, Integer planId, Integer orderType) {
        return tmsTruckFeign.getAllTruckOrder(orderStatus, planId, orderType);
    }

    @ApiOperation(value = "查询所有空闲的运力信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(85)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllCapacity")
    public RESTfulResult getAllCapacity(@RequestBody(required = false) Map<String, Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize,
                                        Integer carrierId
    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsTruckFeign.getAllCapacity(mapValue, apiId, pageNum, pageSize, carrierId);
    }

    @ApiOperation(value = "分解运输计划后 新增订单  或者直接新增订单 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/addPurOrder")
    public RESTfulResult addPurOrder(@RequestBody(required = false) Map<String, Object> mapValue) {
        return tmsTruckFeign.addPurOrder(mapValue);
    }
    // == null ? new HashMap<>() : mapValue


    @ApiOperation(value = "修改分派计划")
    @PostMapping("/updateOrder")
    public RESTfulResult updateOrder(@RequestBody Map<String, Object> map) {
        return tmsTruckFeign.updateOrder(map);
    }


    @ApiOperation(value = "派单")
    @PostMapping("/dispatchOrder/{orderId}")
    public RESTfulResult dispatchOrder(@PathVariable("orderId") Integer orderId) {
        return tmsTruckFeign.dispatchOrder(orderId);
    }

    @ApiOperation(value = "逻辑删除运单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/deleteOrder")
    public RESTfulResult deleteOrder(@RequestBody(required = false) Map<String, Object> map,
                                     Integer planId) {
        return tmsTruckFeign.deleteOrder(map, planId);
    }

    @ApiOperation(value = "司机接收、拒绝接单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "运输订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/driverReceiveOrRefuse/{orderId}")
    public RESTfulResult driverReceiveOrRefuse(@PathVariable("orderId") Integer orderId, Integer orderReceiveStatus) {
        return tmsTruckFeign.driverReceiveOrRefuse(orderId, orderReceiveStatus);
    }


    @ApiOperation(value="司机接单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(117)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getReceiveRefuseOrder/{orderReceiveStatus}")
    public RESTfulResult getReceiveRefuseOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               @PathVariable Integer orderReceiveStatus,
                                               Integer orderType,
                                               Integer orderStatus
    ){
        return tmsTruckFeign.getReceiveRefuseOrder(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum,
                                                    pageSize, orderReceiveStatus, orderType, orderStatus);
    }


    @ApiOperation(value="司机APP端调用接口查询数据 4 已下发 5 已接收")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "capacityNumber", value = "车牌号", required = false, dataType = "String"),
    })
    @PostMapping("/sendMesToDriver")
    public RESTfulResult sendMesToDriver(String capacityNumber, Integer orderStatus){
        return tmsTruckFeign.sendMesToDriver(capacityNumber, orderStatus);
    }

    @ApiOperation(value="通过车牌获取所有已拒绝的订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "capacityNumber", value = "车牌号", required = false, dataType = "String"),
    })
    @PostMapping("/getRefuseOrderByCapacityNum")
    public RESTfulResult sendMesToDriver(String capacityNumber){
        return tmsTruckFeign.sendMesToDriver(capacityNumber);
    }

    @ApiOperation(value="通过运输订单ID查询运单信息 包含各个作业路径")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/getOrderMesByOrderNum/{orderId}")
    public RESTfulResult getOrderMesByOrderNum(@PathVariable("orderId") Integer orderId){
        return tmsTruckFeign.getOrderMesByOrderNum(orderId);
    }

    @ApiOperation(value="通过运输订单ID查询实绩地点和时间")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "运输订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectPlaceAndTime/{orderId}")
    public RESTfulResult selectPlaceAndTime(@PathVariable("orderId") Integer orderId){
        return tmsTruckFeign.selectPlaceAndTime(orderId);
    }

    @ApiOperation(value="通过运输订单ID查询运单信息")
    @PostMapping("/selectOrderByOrderId/{orderId}")
    public RESTfulResult selectOrderByOrderId(@PathVariable("orderId") Integer orderId){
        return tmsTruckFeign.selectOrderByOrderId(orderId);
    }

    @ApiOperation(value="查看运输派单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(117)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getTransportDispatch/{orderReceiveStatus}")
    public RESTfulResult getTransportDispatch(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              @PathVariable Integer orderReceiveStatus,
                                              Integer orderType,
                                              Integer orderStatus){
        return tmsTruckFeign.getTransportDispatch(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize,
                                            orderReceiveStatus, orderType, orderStatus);
    }

    //******************************************TmstruckLoadResultController***********************************

    @ApiOperation(value="查询所有装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(91)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllLoadResult")
    public RESTfulResult getAllLoadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer status ){
        return tmsTruckFeign.getAllLoadResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, status);
    }

    @ApiOperation(value="新增汽车装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/addLoadResult")
    public RESTfulResult addLoadResult(@RequestBody(required=false) Map<String,Object> mapValue){
        return  tmsTruckFeign.addLoadResult(mapValue);
    }

    @ApiOperation(value="修改汽车装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstruckLoadResult", value = "装车作业实绩对象", required = false, dataType = "TmstruckLoadResult"),
    })
    @PostMapping("/updateLoadResult")
    public RESTfulResult updateLoadResult(@RequestBody Map<String, Object> map){
        return tmsTruckFeign.updateLoadResult(map);
    }

    @ApiOperation(value="通过ID查询装车实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "装车作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/getLoadResultById/{resultId}")
    public RESTfulResult getLoadResultById(@PathVariable("resultId") Integer resultId){
        return tmsTruckFeign.getLoadResultById(resultId);
    }

    @ApiOperation(value="逻辑删除车装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstruckLoadResult", value = "装车作业实绩对象", required = false, dataType = "TmstruckLoadResult"),
    })
    @PostMapping("/deleteLoadResult/{resultId}")
    public RESTfulResult deleteLoadResult(@PathVariable("resultId")Integer resultId){
        return tmsTruckFeign.deleteLoadResult(resultId);
    }

    //***************************************TmstruckEnfactoryResultController***************************

    @ApiOperation(value="查询所有的进厂实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(99)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllEnFactoryResult")
    public RESTfulResult getAllEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize
    ){
        return tmsTruckFeign.getAllEnFactoryResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="通过采集系统传来的数据新增进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/addEnFactoryResult")
    public RESTfulResult addEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue){
        return tmsTruckFeign.addEnFactoryResult(mapValue);
    }

    @ApiOperation(value="PDA扫描更新进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/updateEnactoryResult")
    public RESTfulResult updateEnactoryResult(@RequestBody(required=false) Map<String,Object> mapValue){
        return tmsTruckFeign.updateEnactoryResult(mapValue);
    }

    //***************************************TmstruckWeightResultController***************************
    @ApiOperation(value="查询计毛实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(102)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllJiMaoResult")
    public RESTfulResult getAllJiMaoResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize){
        return tmsTruckFeign.getAllJiMaoResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="查询计皮实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(104)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllJiPiResult")
    public RESTfulResult getAllJiPiResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize) {
        return tmsTruckFeign.getAllJiPiResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }


    @ApiOperation(value="采集新增计毛实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "采集的数据", required = false, dataType = "Map"),
    })
    @PostMapping("/addJiMaoResult")
    public RESTfulResult addJiMaoResult(@RequestBody Map<String, Object> mapValue){
        return tmsTruckFeign.addJiMaoResult(mapValue);
    }

    @ApiOperation(value="采集新增计皮实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "采集的数据", required = false, dataType = "Map"),
    })
    @PostMapping("/addJiPiResult")
    public RESTfulResult addJiPiResult(@RequestBody Map<String, Object> mapValue){
        return tmsTruckFeign.addJiPiResult(mapValue);
    }

    //****************************************TmstruckUnloadResultController*******************************

    @ApiOperation(value="查询卸货实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(103)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getUnloadResult")
    public RESTfulResult getUnloadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize
    ){
        return tmsTruckFeign.getUnloadResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="更新卸货实绩 实际上是更新实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "装车作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/addUnloadResult")
    public RESTfulResult addUnloadResult(@RequestBody Map<String, Object> mapValue){
        return tmsTruckFeign.addUnloadResult(mapValue);
    }

    //****************************************TmstruckReceiptResultController*******************************


    @ApiOperation(value="查询收货实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(107)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getReceiveResult")
    public RESTfulResult getReceiveResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize
    ){
        return tmsTruckFeign.getReceiveResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }


    //****************************************TmstruckLeaveFactoryResultController*******************************


    @ApiOperation(value="查询出厂实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(110)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getLeaveFactoryResult")
    public RESTfulResult getLeaveFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize
    ){
        return tmsTruckFeign.getLeaveFactoryResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="PAD扫描汽车出厂实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/addLeaveFactoryResult")
    public RESTfulResult addLeaveFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue){
        return tmsTruckFeign.addLeaveFactoryResult(mapValue);
    }

    //****************************************TmstruckMeasureCommissionController*******************************

    @ApiOperation(value="查询计量委托 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "装车作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllMeasureCommission/{type}")
    public RESTfulResult getAllMeasureCommission(@PathVariable("type") Integer type){
        return tmsTruckFeign.getAllMeasureCommission(type);
    }

    //****************************************TmstruckQualityResultController*******************************

    @ApiOperation(value="查询所有的质检作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(111)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQualityResult")
    public RESTfulResult getQualityResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize
    ){
        return tmsTruckFeign.getQualityResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize);
    }

    @ApiOperation(value="通过ID获取质检实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "质检作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQualityResultById/{resultId}")
    public RESTfulResult getQualityResultById(@PathVariable("resultId") Integer resultId){
        return tmsTruckFeign.getQualityResultById(resultId);
    }

    @ApiOperation(value="修改质检实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "质检作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/updateQualityResult")
    public RESTfulResult updateQualityResult(@RequestBody(required=false) Map<String,Object> mapValue){
        return tmsTruckFeign.updateQualityResult(mapValue);
    }



}