package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/23 8:46
 * @Version:V2.0
 */
@FeignClient(value = "DIL-AMS-API-DEV", url = "${openfeign.AmsFeign.url}")
public interface AmsFeign {

    /**
     * 展示违约规则
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/getBreachList")
    RESTfulResult getBreachList(@RequestBody(required = false) Map<String, Object> mapValue,
                                @RequestParam("pageNum") Integer pageNum,
                                @RequestParam("pageSize") Integer pageSize,
                                @RequestParam("apiId") Integer apiId);

    /**
     * 新增违约规则
     *
     * @param amsContractBreach
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/addContractBreach")
    RESTfulResult addContractBreach(@RequestBody Map<String, Object> amsContractBreach);

    /**
     * 逻辑删除违约规则
     *
     * @param breachId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/deleteContractBreach/{breachId}")
    RESTfulResult deleteContractBreach(@PathVariable("breachId") BigDecimal breachId);

    /**
     * 通过违约id查询
     *
     * @param breachId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/selectBreachToUpdate/{breachId}")
    RESTfulResult selectBreachToUpdate(@PathVariable("breachId") BigDecimal breachId);

    /**
     * 修改违约规则
     *
     * @param amsContractBreach
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/updateContractBreach")
    RESTfulResult updateContractBreach(@RequestBody Map<String, Object> amsContractBreach);

    /**
     * 展示港口装卸单价列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/getLoadUnloadPriceList")
    RESTfulResult getLoadUnloadPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                         @RequestParam Integer pageNum,
                                         @RequestParam Integer pageSize,
                                         @RequestParam Integer apiId);

    /**
     * 新增港口装卸单价
     *
     * @param amsContractOtherPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/addLoadUnloadPrice")
    RESTfulResult addLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice);

    /**
     * 逻辑删除港口装卸单价
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/deleteLoadUnloadPrice/{priceId}")
    RESTfulResult deleteLoadUnloadPrice(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 通过单价id查询
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/selectLoadUnloadPriceToUpdate/{priceId}")
    RESTfulResult selectLoadUnloadPriceToUpdate(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 修改港口装卸单价
     *
     * @param amsContractOtherPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/updateLoadUnloadPrice")
    RESTfulResult updateLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice);


    /**
     * 展示火运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/getTrainPriceList")
    RESTfulResult getTrainPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam Integer pageNum,
                                    @RequestParam Integer pageSize,
                                    @RequestParam Integer apiId);

    /**
     * 新增火运单价
     *
     * @param amsContractTrainPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/addTrainPrice")
    RESTfulResult addTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice);

    /**
     * 逻辑删除火运单价
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/deleteTrainPrice/{priceId}")
    RESTfulResult deleteTrainPrice(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 通过单价id查询
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/selectTrainPriceToUpdate/{priceId}")
    RESTfulResult selectTrainPriceToUpdate(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 修改火运单价
     *
     * @param amsContractTrainPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/updateTrainPrice")
    RESTfulResult updateTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice);


    /**
     * 展示水运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/getShipPriceList")
    RESTfulResult getShipPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                   @RequestParam Integer pageNum,
                                   @RequestParam Integer pageSize,
                                   @RequestParam Integer apiId);

    /**
     * 新增水运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/addShipPrice")
    RESTfulResult addShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 逻辑删除运费单价
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/deleteShipPrice/{priceId}")
    RESTfulResult deleteShipPrice(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 修改水运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/updateShipPrice")
    RESTfulResult updateShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 通过单价id查询
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/selectPriceToUpdate/{priceId}")
    RESTfulResult selectPriceToUpdate(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 展示汽运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/getTruckPriceList")
    RESTfulResult getTruckPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam Integer pageNum,
                                    @RequestParam Integer pageSize,
                                    @RequestParam Integer apiId);

    /**
     * 新增汽运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/addAmsContractTransportPrice")
    RESTfulResult addAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 修改汽运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/updateAmsContractTransportPrice")
    RESTfulResult updateAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 油价联动导致运价变动，批量修改运价
     *
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/batchUpdateTransportPriceByOilPrice")
    RESTfulResult batchUpdateTransportPriceByOilPrice();

    /**
     * 展示采购订单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amspurchaseorders/getPurchaseOrderList")
    RESTfulResult getPurchaseOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);

    /**
     * 下拉框
     * @return
     */
    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getAddressDeliveryAddress")
    RESTfulResult getAddressDeliveryAddress();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getShipperId")
    RESTfulResult getShipperId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getCarrierId")
    RESTfulResult getCarrierId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getCapacityId")
    RESTfulResult getCapacityId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getMaterialId")
    RESTfulResult getMaterialId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getTruckCapacityId")
    RESTfulResult getTruckCapacityId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getLineId")
    RESTfulResult getLineId();

}