package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.math.BigDecimal;
import java.util.Map;

/**
 * @Description:BmsshipFeign
 * @Author:HuJianGuo
 * @GreateTime:2021/9/23 8:46
 * @Version:V2.0
 */
@FeignClient(value = "DIL-BMSTRAIN-API-DEV", url = "${openfeign.BmstrainFeign.url}")
public interface BmstrainFeign {

    /**
     * 展示火运详单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstraindetailsorders/getTrainDetailsOrderList")
    RESTfulResult getTrainDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           @RequestParam Integer pageNum,
                                           @RequestParam Integer pageSize,
                                           @RequestParam Integer apiId);

    /**
     * 展示未转账单的火运详单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstraindetailsorders/getUncomplateTrainDetailsList")
    RESTfulResult getUncomplateTrainDetailsList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                @RequestParam Integer pageNum,
                                                @RequestParam Integer pageSize,
                                                @RequestParam Integer apiId);

    /**
     * 展示火运实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstraindetailsorders/getTrainResultList")
    RESTfulResult getTrainResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam Integer pageNum,
                                     @RequestParam Integer pageSize,
                                     @RequestParam Integer apiId);

    /**
     * 生成火运详单
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstraindetailsorders/addTrainDetails")
    RESTfulResult addTrainDetails(@RequestBody Map<String, Object> map);

    /**
     * 展示火运账单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainstatement/getTrainStatementList")
    RESTfulResult getTrainStatementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize,
                                        @RequestParam Integer apiId);

    /**
     * 展示火运实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainstatement/getStatementTrainResultList")
    RESTfulResult getStatementTrainResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                              @RequestParam Integer pageNum,
                                              @RequestParam Integer pageSize,
                                              @RequestParam Integer apiId,
                                              @RequestParam Integer detailsId);

    /**
     * 展示账单下的详单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainstatement/getComplateTrainDetailsList")
    RESTfulResult getComplateTrainDetailsList(@RequestParam BigDecimal batchId,
                                              @RequestBody(required = false) Map<String, Object> mapValue,
                                              @RequestParam Integer pageNum,
                                              @RequestParam Integer pageSize,
                                              @RequestParam Integer apiId,
                                              @RequestParam BigDecimal statementId);

    /**
     * 生成火运费账单
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainstatement/addTrainStatement")
    RESTfulResult addTrainStatement(@RequestBody Map<String, Object> map);

}