package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @ author    :TXF
 * @ time      :2021/9/28 9:30
 */

@FeignClient(name = "dil-tms-truck-dev", url = "${openfeign.TmsTruckFeign.url}")
public interface TmsTruckFeign {

    /*
        AmstruckPurplanController中所有接口
     */
    @PostMapping("api/v1/truckTms/amstruckpurplans/getAllPurPlan")
    RESTfulResult getAllPurPlan(@RequestBody(required=false) Map<String,Object> mapValue,
                                @RequestParam("apiId") Integer apiId,
                                @RequestParam("pageNum") Integer pageNum,
                                @RequestParam("pageSize") Integer pageSize,
                                @RequestParam("status") Integer status);

    @PostMapping("api/v1/truckTms/amstruckpurplans/getAllPurPlan/{apiId}")
    public RESTfulResult getDetailListByCon(@PathVariable("apiId") Integer apiId,
                                            @RequestBody(required=false) Map<String,Object> mapValue,
                                            @RequestParam("pageNum")Integer pageNum,
                                            @RequestParam("pageSize")Integer pageSize,
                                            @RequestParam("con")String con);

    @PostMapping ("api/v1/truckTms/amstruckpurplans/getPurPlanById/{planId}")
    public RESTfulResult getPurPlanById(@PathVariable("planId")Integer planId);

    @PostMapping("api/v1/truckTms/amstruckpurplans/addPurPlan")
    public RESTfulResult addPurPlan(@RequestBody Map<String, Object> map);

    @PostMapping("api/v1/truckTms/amstruckpurplans/sendPurPlan/{planId}")
    public RESTfulResult sendPurPlan(@PathVariable("planId")Integer planId);

    @PostMapping("api/v1/truckTms/amstruckpurplans/receptionPurPlan/{planId}")
    public RESTfulResult receptionPurPlan(@PathVariable("planId")Integer planId);



    @PostMapping("api/v1/truckTms/amstruckpurplans/deletePurPlan/{planId}")
    public RESTfulResult deletePurPlan(@PathVariable("planId")Integer planId);

    @PostMapping("api/v1/truckTms/amstruckpurplans/getDecomposedPlan")
    public RESTfulResult getDecomposedPlan(@RequestBody(required=false) Map<String,Object> mapValue,
                                           @RequestParam("apiId") Integer apiId,
                                           @RequestParam("pageNum") Integer pageNum,
                                           @RequestParam("pageSize") Integer pageSize,
                                           @RequestParam("planId") Integer planId,
                                           @RequestParam("status") Integer status);


    /*
    OmstruckOrderController
     */

    @PostMapping("api/v1/truckTms/omstruckorders/getAllTruckOrder")
    public RESTfulResult getAllTruckOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("orderStatus") Integer orderStatus,
                                          @RequestParam("planId") Integer planId,
                                          @RequestParam("orderType") Integer orderType);

    @PostMapping("api/v1/truckTms/omstruckorders/getAllTruckOrderReturnListMap")
    public RESTfulResult getAllTruckOrder(
            @RequestParam("orderStatus") Integer orderStatus,
            @RequestParam("planId") Integer planId,
            @RequestParam("orderType") Integer orderType);

    @PostMapping("api/v1/truckTms/omstruckorders/getAllCapacity")
    public RESTfulResult getAllCapacity(@RequestBody(required=false) Map<String,Object> mapValue,
                                        @RequestParam("apiId") Integer apiId,
                                        @RequestParam("pageNum") Integer pageNum,
                                        @RequestParam("pageSize") Integer pageSize,
                                        @RequestParam("carrierId") Integer carrierId);

    @PostMapping("api/v1/truckTms/omstruckorders/addPurOrder")
    public RESTfulResult addPurOrder(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/truckTms/omstruckorders/updateOrder")
    public RESTfulResult updateOrder(@RequestBody Map<String, Object> map);

    @PostMapping("api/v1/truckTms/omstruckorders/dispatchOrder/{orderId}")
    public RESTfulResult dispatchOrder(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/truckTms/omstruckorders/deleteOrder")
    public RESTfulResult deleteOrder(@RequestBody(required = false) Map<String, Object> map,
                                     @RequestParam("planId") Integer planId);

    @PostMapping("api/v1/truckTms/omstruckorders/driverReceiveOrRefuse/{orderId}")
    public RESTfulResult driverReceiveOrRefuse(@PathVariable("orderId") Integer orderId,
                                               @RequestParam("orderReceiveStatus") Integer orderReceiveStatus);

    @PostMapping("api/v1/truckTms/omstruckorders/getReceiveRefuseOrder/{orderReceiveStatus}")
    public RESTfulResult getReceiveRefuseOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @PathVariable("orderReceiveStatus") Integer orderReceiveStatus,
                                               @RequestParam("orderType") Integer orderType,
                                               @RequestParam("orderStatus") Integer orderStatus);

    @PostMapping("api/v1/truckTms/omstruckorders/sendMesToDriver")
    public RESTfulResult sendMesToDriver(@RequestParam("capacityNumber") String capacityNumber,
                                         @RequestParam("orderStatus") Integer orderStatus);


    @PostMapping("api/v1/truckTms/omstruckorders/getRefuseOrderByCapacityNum")
    public RESTfulResult sendMesToDriver(@RequestParam("capacityNumber") String capacityNumber);


    @PostMapping("api/v1/truckTms/omstruckorders/getOrderMesByOrderNum/{orderId}")
    public RESTfulResult getOrderMesByOrderNum(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/truckTms/omstruckorders/selectPlaceAndTime/{orderId}")
    public RESTfulResult selectPlaceAndTime(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/truckTms/omstruckorders/selectOrderByOrderId/{orderId}")
    public RESTfulResult selectOrderByOrderId(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/truckTms/omstruckorders/getTransportDispatch/{orderReceiveStatus}")
    public RESTfulResult getTransportDispatch(@RequestBody(required=false) Map<String,Object> mapValue,
                                              @RequestParam("apiId") Integer apiId,
                                              @RequestParam("pageNum") Integer pageNum,
                                              @RequestParam("pageSize") Integer pageSize,
                                              @PathVariable("orderReceiveStatus") Integer orderReceiveStatus,
                                              @RequestParam("orderType") Integer orderType,
                                              @RequestParam("orderStatus") Integer orderStatus);

    /*
    TmstruckLoadResultController
     */
    @PostMapping("api/v1/truckTms/tmstruckloadresults/getAllLoadResult")
    public RESTfulResult getAllLoadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("status") Integer status );

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addLoadResult")
    public RESTfulResult addLoadResult(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/updateLoadResult")
    public RESTfulResult updateLoadResult(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/getLoadResultById/{resultId}")
    public RESTfulResult getLoadResultById(@PathVariable("resultId") Integer resultId);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/deleteLoadResult/{resultId}")
    public RESTfulResult deleteLoadResult(@PathVariable("resultId")Integer resultId);
    /*
        TmstruckEnfactoryResultController
     */

    @ApiOperation(value="查询所有的进厂实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(99)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/getAllEnFactoryResult")
    public RESTfulResult getAllEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize
    );


    @ApiOperation(value="通过采集系统传来的数据新增进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/addEnFactoryResult")
    public RESTfulResult addEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue);


    @ApiOperation(value="PDA扫描更新进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/updateEnactoryResult")
    public RESTfulResult updateEnactoryResult(@RequestBody(required=false) Map<String,Object> mapValue);


    /*
        TmstruckWeightResultController
     */

    @PostMapping("api/v1/truckTms/tmstruckweightresults/getAllJiMaoResult")
    public RESTfulResult getAllJiMaoResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                           @RequestParam("apiId") Integer apiId,
                                           @RequestParam("pageNum") Integer pageNum,
                                           @RequestParam("pageSize") Integer pageSize);

    @PostMapping("api/v1/truckTms/tmstruckweightresults/getAllJiPiResult")
    public RESTfulResult getAllJiPiResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize);

    @PostMapping("api/v1/truckTms/tmstruckweightresults/addJiMaoResult")
    public RESTfulResult addJiMaoResult(@RequestBody Map<String, Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckweightresults/addJiPiResult")
    public RESTfulResult addJiPiResult(@RequestBody Map<String, Object> mapValue);


    /*
     TmstruckUnloadResultController
     */

    @PostMapping("api/v1/truckTms/tmstruckunloadresult/getUnloadResult")
    public RESTfulResult getUnloadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                         @RequestParam("apiId") Integer apiId,
                                         @RequestParam("pageNum") Integer pageNum,
                                         @RequestParam("pageSize") Integer pageSize);

    @PostMapping("api/v1/truckTms/tmstruckunloadresult/addUnloadResult")
    public RESTfulResult addUnloadResult(@RequestBody Map<String, Object> mapValue);


    /*
    TmstruckReceiptResultController
     */


    @PostMapping("api/v1/truckTms/tmstruckreceiptresults/getReceiveResult")
    public RESTfulResult getReceiveResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize);

    /*
    TmstruckLeaveFactoryResultController
     */


    @PostMapping("api/v1/truckTms/tmstruckleavefactoryresults/getLeaveFactoryResult")
    public RESTfulResult getLeaveFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize);

    @PostMapping("api/v1/truckTms/tmstruckleavefactoryresults/addLeaveFactoryResult")
    public RESTfulResult addLeaveFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue);


    /*
    TmstruckMeasureCommissionController
     */

    @PostMapping("api/v1/truckTms/tmstruckmeasurecommissions/getAllMeasureCommission/{type}")
    public RESTfulResult getAllMeasureCommission(@PathVariable("type") Integer type);


    /*
    TmstruckQualityResultController
     */
    @PostMapping("api/v1/truckTms/tmstruckqualityresults/getQualityResult")
    public RESTfulResult getQualityResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize);


    @PostMapping("api/v1/truckTms/tmstruckqualityresults/getQualityResultById/{resultId}")
    public RESTfulResult getQualityResultById(@PathVariable("resultId") Integer resultId);


    @PostMapping("api/v1/truckTms/tmstruckqualityresults/updateQualityResult")
    public RESTfulResult updateQualityResult(@RequestBody(required=false) Map<String,Object> mapValue);

    /**
     * 下拉框
     */
    @GetMapping("api/v1/truckTms/dropDown/getDilBatch")
    RESTfulResult getDilBatch();

    @GetMapping("api/v1/truckTms/dropDown/getCarrier")
    RESTfulResult getCarrier();

    @GetMapping("api/v1/truckTms/dropDown/getLine")
    RESTfulResult getLine();

    @GetMapping("api/v1/truckTms/dropDown/getWarehouse")
    RESTfulResult getWarehouse();

    @GetMapping("api/v1/truckTms/dropDown/getGatepost")
    RESTfulResult getGatepost();

    @GetMapping("api/v1/truckTms/dropDown/getAPO")
    RESTfulResult getAPO();

    @GetMapping("api/v1/truckTms/dropDown/getFuCapacityId")
    RESTfulResult getFuCapacityId();

    @GetMapping("api/v1/truckTms/dropDown/getPort")
    RESTfulResult getPort();
}


