package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/23 8:46
 * @Version:V2.0
 */
@FeignClient(value = "DIL-SHIPTMS-API-DEV", url = "${openfeign.TmsshipFeign.url}")
public interface TmsshipFeign {

    /**
     * 展示驳船
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/getBargeOperationList")
    RESTfulResult getBargeOperationList(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize,
                                        @RequestParam Integer apiId);

    /**
     * 查询驳船作业信息
     *
     * @param bargeOperationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/getBargeOperation/{bargeOperationId}")
    RESTfulResult getBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId);

    /**
     * 查询驳船作业信息
     *
     * @param bargeOperationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/selectBargeOperation/{bargeOperationId}")
    RESTfulResult selectBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId);

    /**
     * 删除驳船作业信息
     *
     * @param bargeOperationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/deleteBargeOperation/{bargeOperationId}")
    RESTfulResult deleteBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId);

    /**
     * 修改驳船作业信息
     *
     * @param tmsshipBargeOperation
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/updateBargeOperation")
    RESTfulResult updateBargeOperation(@RequestBody Map<String, Object> tmsshipBargeOperation);

    /**
     * 新增驳船作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/addBargeOperation")
    RESTfulResult addBargeOperation(@RequestBody Map<String, Object> map);

    /**
     * 新增抵达实绩
     *
     * @param mapVal
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipentrywharyresults/addTmsShipEntryWharyResult")
    RESTfulResult addTmsShipEntryWharyResult(@RequestBody Map<String, Object> mapVal);

    /**
     * 新增离港实绩
     *
     * @param mapVal
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipoutwharyresults/addTmsShipOutWharyResult")
    RESTfulResult addTmsShipOutWharyResult(@RequestBody Map<String, Object> mapVal);

    /**
     * 展示装船作业信息列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/getLoadShipList")
    RESTfulResult getLoadShipList(@RequestBody(required = false) Map<String, Object> mapValue,
                                  @RequestParam Integer pageNum,
                                  @RequestParam Integer pageSize,
                                  @RequestParam Integer apiId);

    /**
     * 查询装船作业表单
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/getLoadShip/{resultId}")
    RESTfulResult getLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 查询装船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/selectLoadShip/{resultId}")
    RESTfulResult selectLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 删除装船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/deleteLoadShip/{resultId}")
    RESTfulResult deleteLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 修改装船作业信息
     *
     * @param tmsshipLoadShipResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/updateLoadShip")
    RESTfulResult updateLoadShip(@RequestBody Map<String, Object> tmsshipLoadShipResult);

    /**
     * 新增装船作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/addLoadShip")
    RESTfulResult addLoadShip(@RequestBody Map<String, Object> map);

    /**
     * 展示位置作业信息列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/getShipLocationList")
    RESTfulResult getShipLocationList(@RequestBody(required = false) Map<String, Object> mapValue,
                                      @RequestParam Integer pageNum,
                                      @RequestParam Integer pageSize,
                                      @RequestParam Integer apiId);

    /**
     * 查询位置作业信息
     *
     * @param locationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/getShipLocation/{locationId}")
    RESTfulResult getShipLocation(@PathVariable("locationId") BigDecimal locationId);

    /**
     * 查询位置作业信息
     *
     * @param locationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/selectShipLocation/{locationId}")
    RESTfulResult selectShipLocation(@PathVariable("locationId") BigDecimal locationId);

    /**
     * 删除位置作业信息
     *
     * @param locationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/deleteShipLocation/{locationId}")
    RESTfulResult deleteShipLocation(@PathVariable("locationId") BigDecimal locationId);

    /**
     * 修改位置作业信息
     *
     * @param tmsshipShipLocation
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/updateShipLocation")
    RESTfulResult updateShipLocation(@RequestBody Map<String, Object> tmsshipShipLocation);

    /**
     * 新增位置作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/addShipLocation")
    RESTfulResult addShipLocation(@RequestBody Map<String, Object> map);

    /**
     * 展示水路货物运单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiptotalresults/listAllOrders")
    RESTfulResult listAllOrders(@RequestBody(required = false) Map<String, Object> mapValue,
                                @RequestParam Integer pageNum,
                                @RequestParam Integer pageSize,
                                @RequestParam Integer apiId);

    /**
     * 展示船只信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiptotalresults/getCapacityList")
    RESTfulResult getCapacityList(@RequestBody(required = false) Map<String, Object> mapValue,
                                  @RequestParam Integer pageNum,
                                  @RequestParam Integer pageSize,
                                  @RequestParam Integer apiId);

    /**
     * 展示卸船作业信息列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/getUnLoadShipList")
    RESTfulResult getUnLoadShipList(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam Integer pageNum,
                                    @RequestParam Integer pageSize,
                                    @RequestParam Integer apiId);

    /**
     * 查询卸船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/getUnloadShip/{resultId}")
    RESTfulResult getUnloadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 查询卸船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/selectUnLoadShip/{resultId}")
    RESTfulResult selectUnLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 删除卸船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/deleteUnLoadShip/{resultId}")
    RESTfulResult deleteUnLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 修改卸船作业信息
     *
     * @param tmsshipUnloadShipResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/updateUnLoadShip")
    RESTfulResult updateUnLoadShip(@RequestBody Map<String, Object> tmsshipUnloadShipResult);

    /**
     * 新增卸船作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/addUnLoadShip")
    RESTfulResult addUnLoadShip(@RequestBody Map<String, Object> map);

    /**
     * 展示水分质检信息列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/getWaterQualityResultList")
    RESTfulResult getWaterQualityResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                            @RequestParam Integer pageNum,
                                            @RequestParam Integer pageSize,
                                            @RequestParam Integer apiId);

    /**
     * 查询水分质检信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/getWaterQuality/{resultId}")
    RESTfulResult getWaterQuality(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 查询水分质检信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/selectWaterQualityResult/{resultId}")
    RESTfulResult selectWaterQualityResult(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 删除水分质检信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/deleteWaterQualityResult/{resultId}")
    RESTfulResult deleteWaterQualityResult(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 修改水分质检作业信息
     *
     * @param tmsshipWaterQualityResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/updateWaterQualityResult")
    RESTfulResult updateWaterQualityResult(@RequestBody Map<String, Object> tmsshipWaterQualityResult);

    /**
     * 新增水分质检作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/addWaterQualityResult")
    RESTfulResult addWaterQualityResult(@RequestBody Map<String, Object> map);

    /**
     * 展示船只信息列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/getCapacities")
    RESTfulResult getCapacities(@RequestParam BigDecimal instructionsId,
                                @RequestBody(required = false) Map<String, Object> mapValue,
                                @RequestParam Integer pageNum,
                                @RequestParam Integer pageSize,
                                @RequestParam Integer apiId);

    /**
     * 新增船只
     *
     * @param omsshipInstructionsCapacity
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/addInstructionsCapacity")
    RESTfulResult addInstructionsCapacity(@RequestBody Map<String, Object> omsshipInstructionsCapacity);

    /**
     * 查询船只
     *
     * @param instructionsCapacityId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/getInstructionsCapacity/{instructionsCapacityId}")
    RESTfulResult getInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId);

    /**
     * 逻辑删除船只
     *
     * @param instructionsCapacityId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/deleteInstructionsCapacity/{instructionsCapacityId}")
    RESTfulResult deleteInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId);

    /**
     * 修改船只信息
     *
     * @param omsshipInstructionsCapacity
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/updateInstructionsCapacity")
    RESTfulResult updateInstructionsCapacity(@RequestBody Map<String, Object> omsshipInstructionsCapacity);

    /**
     * 展示装船指令
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/getShipMentInstructionsList")
    RESTfulResult getShipMentInstructionsList(@RequestBody(required = false) Map<String, Object> mapValue,
                                              @RequestParam Integer pageNum,
                                              @RequestParam Integer pageSize,
                                              @RequestParam Integer apiId);

    /**
     * 查询装船指令
     *
     * @param instructionsId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/getShipmentInstructions/{instructionsId}")
    RESTfulResult getShipmentInstructions(@PathVariable("instructionsId") BigDecimal instructionsId);

    /**
     * 查询装船指令
     *
     * @param shipmentInstructionsId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/updateIssueStatus/{shipmentInstructionsId}")
    RESTfulResult updateIssueStatus(@PathVariable("shipmentInstructionsId") BigDecimal shipmentInstructionsId);

    /**
     * 删除装船指令
     *
     * @param instructionsId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/deleteByPrimaryKey/{instructionsId}")
    RESTfulResult deleteByPrimaryKey(@PathVariable("instructionsId") BigDecimal instructionsId);

    /**
     * 修改装船指令
     *
     * @param omsshipShipmentInstructions
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/updateShipmentInstructions")
    RESTfulResult updateShipmentInstructions(@RequestBody Map<String, Object> omsshipShipmentInstructions);

    /**
     * 新增装船指令
     *
     * @param omsshipShipmentInstructions
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/addShipmentInstructions")
    RESTfulResult addShipmentInstructions(@RequestBody Map<String, Object> omsshipShipmentInstructions);

    /**
     * 下拉框
     * @return
     */
    @GetMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/getGroupId")
    RESTfulResult getGroupId();

    @GetMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/getCargoId")
    RESTfulResult getCargoId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/insertBetchId")
    RESTfulResult insertBetchId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getAttorneyId")
    RESTfulResult getAttorneyId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getNoticeId")
    RESTfulResult getNoticeId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getPortName")
    RESTfulResult getPortName();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getPortId")
    RESTfulResult getPortId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getRmRawId")
    RESTfulResult getRmRawId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getPierId")
    RESTfulResult getPierId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/getResultNumber")
    RESTfulResult getResultNumber();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/getCarrier")
    RESTfulResult getCarrier();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/getShipper")
    RESTfulResult getShipper();

    @GetMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/getOrderId")
    RESTfulResult getTask();

    @GetMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/getCapacityId")
    RESTfulResult getCapacityId();

    @GetMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/getBatchId")
    RESTfulResult getBatchId();

    /**
     * 展示货权转移
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/getAmsshipCargoTranferResultList")
    RESTfulResult getAmsshipCargoTranferResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                   @RequestParam Integer pageNum,
                                                   @RequestParam Integer pageSize,
                                                   @RequestParam Integer apiId);

    /**
     * 新增货权转移
     *
     * @param amsshipCargoTransferResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/insertamsshipCargoTransferResult")
    RESTfulResult insertamsshipCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult);

    /**
     * 逻辑删除货权转移
     *
     * @param cargoTransferResultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/deleteByCargoId/{cargoTransferResultId}")
    RESTfulResult deleteByCargoId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId);

    /**
     * 修改货权转移
     *
     * @param amsshipCargoTransferResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/editCargoTransferResult")
    RESTfulResult editCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult);

    /**
     * 查询货权转移
     *
     * @param cargoTransferResultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/selectByCargoTranferResultId/{cargoTransferResultId}")
    RESTfulResult selectByCargoTranferResultId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId);

    /**
     * 展示提货委托
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getAmsshipDeliveryAttroneyList")
    RESTfulResult getAmsshipDeliveryAttroneyList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                 @RequestParam Integer pageNum,
                                                 @RequestParam Integer pageSize,
                                                 @RequestParam Integer apiId);

    /**
     * 新增提货委托
     *
     * @param amsshipDeliveryAttorney
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/insertshipDeliveryAttorney")
    RESTfulResult insertshipDeliveryAttorney(@RequestBody Map<String, Object> amsshipDeliveryAttorney);

    /**
     * 逻辑删除提货委托
     *
     * @param attorneyId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/deleteByAttorneyId/{attorneyId}")
    RESTfulResult deleteByAttorneyId(@PathVariable("attorneyId") Integer attorneyId);

    /**
     * 修改提货委托
     *
     * @param amsshipDeliveryAttorney
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/editDeliveryAttroney")
    RESTfulResult editDeliveryAttroney(@RequestBody Map<String, Object> amsshipDeliveryAttorney);

    /**
     * 查询提货委托
     *
     * @param attorneyId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getDeliveryAttorneyId/{attorneyId}")
    RESTfulResult getDeliveryAttorneyId(@PathVariable("attorneyId") Integer attorneyId);

    /**
     * 下发提货委托
     *
     * @param attorneyId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/sendDeliveryAttorneyStatus/{attorneyId}")
    RESTfulResult sendDeliveryAttorneyStatus(@PathVariable("attorneyId") Integer attorneyId);

    /**
     * 展示放货通知
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/getshipDeliveryNoticeList")
    RESTfulResult getshipDeliveryNoticeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                            @RequestParam Integer pageNum,
                                            @RequestParam Integer pageSize,
                                            @RequestParam Integer apiId);

    /**
     * 新增放货通知
     *
     * @param amsshipDeliveryNotice
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/insertDeliveryNotice")
    RESTfulResult insertDeliveryNotice(@RequestBody Map<String, Object> amsshipDeliveryNotice);

    /**
     * 逻辑删除放货通知
     *
     * @param noticeId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/deleteByNoticeId/{noticeId}")
    RESTfulResult deleteByNoticeId(@PathVariable("noticeId") Integer noticeId);

    /**
     * 修改放货通知
     *
     * @param amsshipDeliveryNotice
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/editDeliveryNotice")
    RESTfulResult editDeliveryNotice(@RequestBody Map<String, Object> amsshipDeliveryNotice);

    /**
     * 查询放货通知
     *
     * @param noticeId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/selectByNoticeId/{noticeId}")
    RESTfulResult selectByNoticeId(@PathVariable("noticeId") Integer noticeId);

    /**
     * 下发放货通知
     *
     * @param noticeId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/sendDeliveryNotice/{noticeId}")
    RESTfulResult sendDeliveryNotice(@PathVariable("noticeId") Integer noticeId);
}