package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/10/12 9:54
 * @Version:V2.0
 */
@FeignClient(value = "dil-wmsh-api", url = "${openfeign.WMSHFeign.url}")
public interface WMSHFeign {

    /**
     * 展示下游港口港存库库存列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/wmsh/wmshgridmaterials/getUnloadPortStockList")
    RESTfulResult getUnloadPortStockList(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize,
                                        @RequestParam Integer apiId);

    /**
     * 展示万州港港存库库存列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/wmsh/wmshgridmaterials/getLoadPortStockList")
    RESTfulResult getLoadPortStockList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);

    /**
     * 查询所有港存库入库实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/wmsh/wmshinboundresults/getInBoundResult")
    RESTfulResult getInBoundResult(@RequestBody(required = false) Map<String, Object> mapValue,
                               @RequestParam Integer apiId,
                               @RequestParam Integer pageNum,
                               @RequestParam Integer pageSize);

    /**
     * 新增港存库入库实绩
     *
     * @param wmshInboundResult
     * @return
     */
    @PostMapping(value = "/api/v1/wmsh/wmshinboundresults/addWarehousingResult")
    RESTfulResult addWarehousingResult(@RequestBody(required = false) Map<String, Object> wmshInboundResult);

    /**
     * 通过实绩Id查询实绩
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/wmsh/wmshinboundresults/getResultById/{resultId}")
    RESTfulResult getResultById(@PathVariable("resultId") Integer resultId);

    /**
     * 逻辑删除港存库入库实绩
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/wmsh/wmshinboundresults/deleteWareHosingResult/{resultId}")
    RESTfulResult deleteWareHosingResult(@PathVariable("resultId") Integer resultId);

    /**
     * 修改港存库入库实绩
     *
     * @param wmshInboundResult
     * @return
     */
    @PostMapping(value = "/api/v1/wmsh/wmshinboundresults/updateWareHosingResult")
    RESTfulResult updateWareHosingResult(@RequestBody Map<String, Object> wmshInboundResult);

    /**
     * 查询所有港存库出库实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/wmsh/wmshoutboundresults/getOutBoundResult")
    RESTfulResult getOutBoundResult(@RequestBody(required = false) Map<String, Object> mapValue,
                               @RequestParam Integer apiId,
                               @RequestParam Integer pageNum,
                               @RequestParam Integer pageSize);

    /**
     * 添加港存库出库实绩
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/wmsh/wmshoutboundresults/addResult")
    RESTfulResult addResult(@RequestBody(required = false) Map<String, Object> map);
}
